<?php

namespace Litematrimony\Reference\Providers;

use Illuminate\Support\ServiceProvider;

class ReferenceServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'reference');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'reference');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('litematrimony.reference', function ($app) {
            return $this->app->make('Litematrimony\Reference\Reference');
        });

        // Bind Visit to repository
        $this->app->bind(
            'Litematrimony\Reference\Interfaces\VisitRepositoryInterface',
            \Litematrimony\Reference\Repositories\Eloquent\VisitRepository::class
        );        // Bind Shortlist to repository
        $this->app->bind(
            'Litematrimony\Reference\Interfaces\ShortlistRepositoryInterface',
            \Litematrimony\Reference\Repositories\Eloquent\ShortlistRepository::class
        );        // Bind Request to repository
        $this->app->bind(
            'Litematrimony\Reference\Interfaces\RequestRepositoryInterface',
            \Litematrimony\Reference\Repositories\Eloquent\RequestRepository::class
        );

        $this->app->register(\Litematrimony\Reference\Providers\AuthServiceProvider::class);
        
        $this->app->register(\Litematrimony\Reference\Providers\RouteServiceProvider::class);
                
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['litematrimony.reference'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('litematrimony/reference.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/reference')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/reference')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
